#
# spec file for package xdg-desktop-portal-hyprland
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _protocol_version 0.2
Name:           xdg-desktop-portal-hyprland
Version:        1.2.5
Release:        9.2
Summary:        Extended xdg-desktop-portal backend for Hyprland
License:        MIT
Group:          System/Libraries
URL:            https://github.com/hyprwm/xdg-desktop-portal-hyprland
Source0:        https://github.com/hyprwm/xdg-desktop-portal-hyprland/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://github.com/hyprwm/hyprland-protocols/archive/refs/tags/v%{_protocol_version}.tar.gz#/hyprland-protocols-%{_protocol_version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  qt6-base-devel
BuildRequires:  qt6-wayland
BuildRequires:  qt6-wayland-devel
BuildRequires:  qt6-waylandclient-devel
BuildRequires:  qt6-waylandclient-private-devel
BuildRequires:  scdoc >= 1.9.7
BuildRequires:  pkgconfig(gbm) >= 21.3
BuildRequires:  pkgconfig(inih)
BuildRequires:  pkgconfig(libdrm) >= 2.4.109
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpipewire-0.3) >= 0.3.62
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(sdbus-c++)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.24

# Screencasting won't work without pipewire, but it's not a hard dependency.
Recommends:     pipewire >= 0.3.41

# Required since the picker uses qt wayland.
# Not a strict requirement as the portal will fallback to slurp
Recommends:     qt6-wayland

Requires:       xdg-desktop-portal

%description
A fork of xdg-desktop-portal backend for wlroots for Hyprland. It supports
other wlroots-based Wayland compositors too with some limitations.

%package -n hyprland-protocols-devel
Summary:        Development files for Hyprland protocols
Group:          Development/Libraries/Other
Version:        0.2
BuildArch:      noarch
Provides:       hyprland-protocols-devel = %{_protocol_version}

%description -n hyprland-protocols-devel
Wayland protocol extensions for interacting or modifying Hyprland.

%prep
%autosetup -p1

# Needed for this portal to work.
tar xvf %{SOURCE1} -C subprojects/hyprland-protocols --strip-components=1

%build
# We need to build hyprland protocols so it can be installed.
pushd subprojects/hyprland-protocols
%meson
%meson_build
popd

%meson
%meson_build

%install

# Install the protocols
pushd subprojects/hyprland-protocols
%meson_install
popd

%meson_install

%pre
%systemd_user_pre %{name}.service

%post
%systemd_user_post %{name}.service

%preun
%systemd_user_preun %{name}.service

%postun
%systemd_user_postun %{name}.service

%files
%{-,root,root,-}
%license LICENSE
%doc README.md CONTRIBUTING.md
%{_bindir}/hyprland-share-picker
%{_libexecdir}/%{name}
%dir %{_datadir}/xdg-desktop-portal
%dir %{_datadir}/xdg-desktop-portal/portals
%{_datadir}/dbus-1/services/org.freedesktop.impl.portal.desktop.hyprland.service
%{_datadir}/xdg-desktop-portal/portals/hyprland.portal
%{_userunitdir}/%{name}.service

%files -n hyprland-protocols-devel
%{_datadir}/pkgconfig/hyprland-protocols.pc
%dir %{_datadir}/hyprland-protocols
%dir %{_datadir}/hyprland-protocols/protocols
%{_datadir}/hyprland-protocols/protocols/*

%changelog
* Tue Nov 28 2023 malcolmlewis@opensuse.org
- Update to version 1.2.5:
  * Added back screenshot functionality,
    (gh#hyprwm/xdg-desktop-portal-hyprland#127).
  * VRAM leak fixes.
  * Destroy pipewire streams when ScreenCast sessions are closed,
    (gh#hyprwm/xdg-desktop-portal-hyprland#130).
- Changes from version 1.2.4:
  * portal: remove screenshot cap from .portal file.
  * Default meson build type to release,
    (gh#hyprwm/xdg-desktop-portal-hyprland#125).
* Sun Oct 22 2023 Nicolas Lorin <androw95220@gmail.com>
- Update to version 1.2.3:
  * Small update still fixing more edge cases causing a CPU core spike after exit.
* Sun Oct 15 2023 Nicolas Lorin <androw95220@gmail.com>
- Update to version 1.2.2:
  * Unbreak build on FreeBSD
  * Fix build when using clang
  * specify flag for manual installation
  * fixes the picker starting at windows and not monitors
  * performance improvements
  * fix for high CPU usage after exit
  * hotfix to 1.2.0 to fix crashes after a few seconds
  * fix some issues with screensharing on non-linear dmabuf GPUs
  * fix xdph not exiting on terminate
* Mon Sep 25 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Remove 0000-sdbus-c++-cmake-lists.patch
- Remove conflicts with XDG-wlr. XDP 0.18.0 introduces flexible
  configuration of portals.
- Update to version 1.1.0:
  * core: rework event loop for polling and C++-style awaits
  * internal: make frame callbacks log a trace
  * internal: add a notification on missing qt-wayland packages
  * drop unused dependencies
  * fix build system
  * add double escaping
* Sat Sep  9 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add back cmake. Seems they forgotten share picker on the meson.build
* Sat Sep  9 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Further correct mistake by installing of systemd services properly.
* Sat Sep  9 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Revert using cmake and go back using meson
* Thu Sep  7 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix build and install for hyprland protocol and the portal
* Thu Sep  7 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Use sdb-c++ from system instead of subproject through cmake patch:
  0000-sdbus-c++-cmake-lists.patch
* Thu Sep  7 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add libjpeg, cairo, pango(cairo) as deps
* Thu Sep  7 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Use cmake instead of meson.
* Wed Sep  6 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.0.0:
  * added sdbus-c++ as dependency
  * this release is a full rewrite from C to C++
* Thu Aug 17 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.5.0:
  * pw: guard output in transform checks
  * toplevelexport: remove _done call from _buffer
  * screencast: correct array size
* Tue May 30 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.4.0:
  * screencast: restore window by class
  * some nix stuff
* Mon May 22 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Remove some -devel dependencies because this is a runtime package.
* Sat May 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Cleanup dependencies
- Hyprland-protocols now uses tag releases
- Improve specfile
- Update xdg-desktop-portal-hyprland to 0.3.1:
  * pw: send transform to pipewire
  * fix implicit function declaration
  * fix build after commit 7d3da7e
* Sun Apr 23 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Make shorter summary but longer description.
* Sun Apr 23 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Set hyprland-protocols-devel to noarch.
* Sun Apr 23 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Create hyprland-protocols-devel package.
  * Assign files for this package.
- Add qt wayland libraries and packages as recommends as they are really
  used for the picker. Not strictly a requirement since it will fallback
  to slurp.
* Sun Apr 16 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for xdg-desktop-portal-hyprland 0.2.1
